   pro taskfig01,iout,figsub

; ifig01=15 Do a bw version of Figure 1 from scratch

; ******************************
; Helpful for conversions
    radius=6370.0
;   pi=3.14159265
    pi=atan(1.)*4.
    circum=2.00*pi*radius
    convr=pi/180.0
; km per degree (110.0)
    conv=circum/360.0

; ******************************
; Specify the array
    nx=64
    ny=64
   xdim=fltarr(nx)
   ydim=fltarr(ny)
   array=fltarr(nx,ny)
   for i=0,nx-1 do begin
    xdim(i)=0.0+(i*0.5)
   endfor
   for i=0,ny-1 do begin
    ydim(i)=0.0+(i*0.5)
   endfor

    awhite=0.0
    adark=0.5
   for i=0,nx-1 do begin
   for j=0,ny-1 do begin
    a1=awhite
    if ((xdim(i) ge 3.0) and (xdim(i) le 6.0)) then begin
     a1=adark
    endif
    if ((xdim(i) ge 26.0) and (xdim(i) le 29.0)) then begin
     a1=adark
    endif
    array(i,j)=a1
   endfor
   endfor

   colc=[240,200,160,120,100,90,80,70,60,50,40]
   clab=[1,1,1,1,1,1,1,1,1,1,1]
   levelsc=[0.02, .1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0 ]

   xitle='KM'
   yitle='KM'
   title=' '

; ******************************
; Output ps file
   fileps=strcompress(figsub+'figure01.ps')
   print,fileps

; ******************************
; create a .ps file
  set_plot, 'ps'
  device, /color, bits_per_pixel=8, file=fileps,$
   /portrait,/inch,ysize=9.0,xsize=7.0,xoffset=0.6,yoffset=1.0

; specify the color palette
; see pg 16-10 of the user's guide
   icolor=0
  if (icolor eq 1) then begin
   loadct, 26
  endif
  if (icolor eq 0) then begin
   loadct, 0
  endif

; For bold type
  !P.font=0

; specify the character size for the labels
  csizet=1.5
  csizel=1.0

; have graphs plus the color bar 
; [ignore,horizontal,vertical]  
    nmult=1
  !P.MULTI=[0,1,nmult]

  xm=4

  x1a=0.25
  x2a=0.75
  y1a=0.25
  y2a=0.75

  xr1=min(xdim)
  xr2=max(xdim)
  yr1=min(ydim)
  yr2=max(ydim)

; ****
  contour, array, xdim, ydim, /cell_fill, $
   levels=levelsc,$
   xmargin=[xm,xm],ymargin=[xm,xm],$
   position=[x1a,y1a,x2a,y2a],$
   xrange=[xr1,xr2],yrange=[yr1,yr2],$
   xstyle=1,ystyle=1,$
   xtitle=xtitle,ytitle=ytitle,$
   title=title,$
   c_charthick=3.0,$
   c_colors=colc,$
   c_labels=clab

; ****
   thick=2
   csize=1.5
   clr=0.0

    x=11.8
    y=25.0
    clabel='Left cloud'
   xyouts,x,y,clabel,alignment=0.5,CHARSIZE=csize,/DATA,CHARTHICK=thick,COLOR=clr

    x=19.7
    y=7.0
    clabel='Right cloud'
   xyouts,x,y,clabel,alignment=0.5,CHARSIZE=csize,/DATA,CHARTHICK=thick,COLOR=clr

; ****
    x=0.15
    y=0.50
    clabel='Sun'
   xyouts,x,y,clabel,alignment=0.5,CHARSIZE=csize,/NORMAL,CHARTHICK=thick,COLOR=clr

    x=0.85
     y=0.65
    clabel='Sensor'
   xyouts,x,y,clabel,alignment=0.5,CHARSIZE=csize,/NORMAL,CHARTHICK=thick,COLOR=clr
    x=0.85
    y=y-0.03
    clabel='Beams'
   xyouts,x,y,clabel,alignment=0.5,CHARSIZE=csize,/NORMAL,CHARTHICK=thick,COLOR=clr

; ****
; In Data coordinates

; distance D from clouds
    xtail=6.0
    ytail=16.0
    xhead=xtail+4.0
    yhead=ytail
    arrow,xtail,ytail,xhead,yhead,/DATA,COLOR=clr,HTHICK=2.0,/SOLID,THICK=thick

    ydown=2.0
    x=0.5*(xtail+xhead)
    y=yhead-ydown
    clabel='D'
   xyouts,x,y,clabel,alignment=0.5,CHARSIZE=csize,/DATA,CHARTHICK=thick,COLOR=clr

     yup=0.5
    x=xhead
    y=yhead+yup
    clabel='Obs'
   xyouts,x,y,clabel,alignment=0.5,CHARSIZE=csize,/DATA,CHARTHICK=thick,COLOR=clr

; ***
    xtail=26.0
    ytail=16.0
    xhead=xtail-4.0
    yhead=ytail
    arrow,xtail,ytail,xhead,yhead,/DATA,COLOR=clr,HTHICK=2.0,/SOLID,THICK=thick

    x=0.5*(xtail+xhead)
    y=yhead-ydown
    clabel='D'
   xyouts,x,y,clabel,alignment=0.5,CHARSIZE=csize,/DATA,CHARTHICK=thick,COLOR=clr

    x=xhead
    y=yhead+yup
    clabel='Obs'
   xyouts,x,y,clabel,alignment=0.5,CHARSIZE=csize,/DATA,CHARTHICK=thick,COLOR=clr

; sensor beams
    xtail=10.0
    ytail=16.0
     xhead=38.0
    yhead=22.0
    arrow,xtail,ytail,xhead,yhead,/DATA,COLOR=clr,HTHICK=2.0,/SOLID,THICK=thick

    xtail=22.0
    ytail=16.0
     xhead=38.0
    yhead=22.0
    arrow,xtail,ytail,xhead,yhead,/DATA,COLOR=clr,HTHICK=2.0,/SOLID,THICK=thick

; ****
  device,/close
  print,fileps

; ******************************
   return
   end
